=========================================
sve_common_tools
=========================================

.. sectnum::

.. contents:: The tiny table of contents

Sve_SSHManager
~~~~~~~~~~~~~~~~~~~~~~~~~

Classe di gestione SSH tramite paramiko

Sve_file_utils
~~~~~~~~~~~~~~~~~~~~~~~~~

Classe di gestione operazioni su blocchi di testo
 - def remove_before_header_string(str, header_str)
 - def remove_after_footer_string(str, footer_str)
 - def remove_skip_rows(str, skip_str_starting_array, skip_empty_lines)
 - def extract_block(str, starting_row, ending_row, add_ending_row)
 - def add_char_to_every_row_if_not_exist(str, character)
 - def parse_extact_table(str, header_column_position)
 - def create_htmltable(command_output_array_table, html_header)

